@@ -406,6 +406,8 @@ my %determiners = (
     'SwfExportOptions' => { 'Format' => 'swf', },
     'Table' => { 'Type' => 'Table', },
     'TableCell' => {  },
+    'TableCellMergeOptions' => {  },
+    'TableCellSplitType' => {  },
     'TableColumn' => {  },
     'TableRow' => {  },
     'Task' => {  },
